@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/denote-org
-;; Version: 0.0.0.1
+;; Version: 0.1.0
 ;; Package-Requires: ((emacs "28.1") (denote "3.1.0"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -32,6 +32,14 @@
 (require 'denote)
 (require 'org)
 
+(defgroup denote-org ()
+  "Optional extensions to Denote that work specifically with Org mode."
+  :group 'denote
+  :link '(info-link "(denote) top")
+  :link '(info-link "(denote-org) top")
+  :link '(url-link :tag "Denote homepage" "https://protesilaos.com/emacs/denote")
+  :link '(url-link :tag "Denote Org homepage" "https://protesilaos.com/emacs/denote-org"))
+
 ;;;; Link to file and heading
 
 (defun denote-org--get-outline (file)
